@@ -18,7 +18,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/cif/CIFrdpt.c,v 1.5 2001/03/29 19:50:04 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/cif/CIFrdpt.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -410,6 +410,59 @@ CIFPaintWirePath(pathheadp, width, endcap, plane, ptable, ui)
     CIFFreePath(pathheadp);
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * PaintPolygon --
+ *
+ * Convert a list of points in the form of an array of type Point to a
+ * CIFPath linked structure, and paint them into the database.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Paints tiles into the layout database.  Calling routine is
+ *	responsible for free'ing memory of the pointlist, if necessary.
+ *
+ * Notes:
+ *	This is a database routine, not a CIF routine.  However, it makes
+ *	use of the CIFPath structure, so it is included here.
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+void
+PaintPolygon(pointlist, number, plane, ptable, ui)
+    Point *pointlist;		/* Array of Point structures */
+    int number;			/* total number of points */
+    Plane *plane;		/* Plane structure to paint into */
+    PaintResultType *ptable;	/* Paint result table */
+    PaintUndoInfo *ui;		/* Undo record */
+{
+    LinkedRect	*rectp;
+    CIFPath *newpath, *cifpath = (CIFPath *)NULL;
+    int i;
+   
+    for (i = 0; i < number; i++)
+    {
+	newpath = (CIFPath *) mallocMagic((unsigned) sizeof (CIFPath));
+	newpath->cifp_x = pointlist[i].p_x;
+	newpath->cifp_y = pointlist[i].p_y;
+	newpath->cifp_next = cifpath;
+	cifpath = newpath;
+    }
+
+    rectp = CIFPolyToRects(cifpath, plane, ptable, ui);
+    CIFFreePath(cifpath);
+
+    for (; rectp != NULL ; rectp = rectp->r_next)
+    {
+	DBPaintPlane(plane, &rectp->r_r, ptable, ui);
+	freeMagic((char *) rectp);
+    }
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
