@@ -22,9 +22,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/comm
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef SYSV
 #include <string.h>
-#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -784,156 +782,6 @@ badusage:
     return;
 }
 
-#ifdef MAGIC_WRAPPER
-/*
- * ----------------------------------------------------------------------------
- *
- * CmdCellsearch --
- *
- *	This is a low-level search command that allows a hierarchical cell
- *	search to execute a TCL procedure on each cell definition or cell
- *	use found.
- *
- *	Use: cellsearch [instances] <tcl_procedure>
- *
- *	If "instances" is present, then the cell search is over all cell
- *	uses, and <tcl_procedure> takes a list containing 4 integer values
- *	representing the bounding box (llx, lly, urx, ury) of the cell,
- *	and two string values containing the name of the cell use and the
- *	cell definition, respectively.
- *
- *	If "instances" is *not* present, then the cell search is over each
- *	cell definition, and <tcl_procedure> takes one value, which is the
- *	name of the cell.
- *
- * ----------------------------------------------------------------------------
- */
-
-void
-CmdCellsearch(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
-{
-    SearchContext scx;
-    int xMask, windowMask;
-    char *tclproc, *pptr;
-    int cmdTclProcSrCellFunc();     /* Fwd declaration */
-    int cmdTclProcCellDefFunc();     /* Fwd declaration */
-    CellDef *rootBoxDef;
-    MagWindow *window;
-
-    bzero(&scx, sizeof(SearchContext));
-    if (!ToolGetBox (&rootBoxDef, NULL))
-    {
-	TxError ("Box tool must be present\n");
-	return;
-    }
-    window = ToolGetBoxWindow (&scx.scx_area, &windowMask);
-    if (!window)
-    {
-	TxError ("Box tool does not exist in any window\n");
-	return;
-    }
-    xMask = ((DBWclientRec *)window->w_clientData)->dbw_bitmask;
-    if ((windowMask & ~xMask) != 0)
-    {
-	window = CmdGetRootPoint((Point *) NULL, (Rect *) NULL);
-	xMask = ((DBWclientRec *) window->w_clientData)->dbw_bitmask;
-	if ((windowMask & xMask) == 0)
-	{
-	    TxPrintf("The box is in more than one window;  use the cursor\n");
-	    TxPrintf("to select the one you want to select from.\n");
-	    return;
-	}
-    }
-    scx.scx_use = (CellUse *) window->w_surfaceID;
-    scx.scx_trans = GeoIdentityTransform;
-
-    if ((cmd->tx_argc == 1) || (cmd->tx_argc > 3))
-    {
-	TxError("Usage: cellsearch [instances] <tcl_procedure>\n");
-	return;
-    }
-
-    pptr = cmd->tx_argv[cmd->tx_argc - 1];
-    if (*pptr == '{')           /* in-line procedure */
-    {
-	tclproc = StrDup(NULL, pptr + 1);
-	pptr = tclproc + strlen(tclproc) - 1;
-	if (*pptr == '}') *pptr = '\0';
-    }
-    else
-	tclproc = StrDup(NULL, cmd->tx_argv[cmd->tx_argc - 1]);
-
-    if ((cmd->tx_argc == 3) && (!strncmp(cmd->tx_argv[1], "inst", 4)))
-    {
-	DBTreeSrTiles(&scx, xMask, cmdTclProcSrCellFunc,
-		(ClientData) tclproc);
-    }
-    else
-    {
-	DBCellSrDefs(0, cmdTclProcCellDefFunc, (ClientData) tclproc);
-    }
-    freeMagic(tclproc);
-}   
-
-/*
- * cmdTclProcSrCellFunc --
- *  
- * Filter procedure applied to cell instances by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcSrCellFunc(scx, tclproc)
-    SearchContext *scx;
-    char *tclproc;
-{
-    Rect rootRect;
-    char evalstr[512];
-    int rval;
-    CellDef *def;
-
-    def = scx->scx_use->cu_def;
-    GeoTransRect(&scx->scx_trans, &def->cd_bbox, &rootRect);
-
-    sprintf(evalstr, "%s %d %d %d %d %s %s", tclproc, rootRect.r_xbot,
-		rootRect.r_ybot, rootRect.r_xtop, rootRect.r_ytop,
-		def->cd_name, scx->scx_use->cu_id);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-/*
- * cmdTclProcCellDefFunc --
- *  
- * Filter procedure applied to celldefs by cmdCellsearch() above.
- */ 
-  
-int
-cmdTclProcCellDefFunc(def, tclproc)
-    CellDef *def;
-    char *tclproc;
-{
-    char evalstr[512];
-    int rval;
-
-    sprintf(evalstr, "%s %s", tclproc, def->cd_name);
-
-    rval = Tcl_EvalEx(magicinterp, evalstr, -1, 0);
-    if (rval != TCL_OK) return 1;
-
-    /* Allow interrupts in case something goes wrong with the Tcl procedure */
-    if (SigInterruptPending) return 1;
-    return 0;
-}   
-
-#endif
-
 /*
  * ----------------------------------------------------------------------------
  *
