@@ -409,13 +409,7 @@ drcTile (tile, arg)
 		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 			cptr = cptr->drcc_next)
 		{
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			ccdist = cptr->drcc_cdist;
-			cdist = cptr->drcc_dist;
-		    }
-		    else
-			cdist = cptr->drcc_cdist;
+		    cdist = cptr->drcc_cdist;
 
 		    /* Contact images exist in multiple planes; only check	*/
 		    /* rules that are for the plane being checked.		*/
@@ -625,32 +619,7 @@ drcTile (tile, arg)
 		    arg->dCD_cptr = cptr;
 		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
 
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			int tmpy = errRect.r_ybot;
-			errRect.r_ybot = edgeTop + ccdist;
-			if (errRect.r_ybot < errRect.r_ytop)
-			{
-			    /* result = 0; */ /* to be finished */
-			    result = DBSrPaintArea((Tile *) NULL,
-				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-				&errRect, &tmpMask, areaCheck, (ClientData) arg);
-			}
-			errRect.r_ybot = tmpy;
-			tmpy = errRect.r_ytop;
-			errRect.r_ytop = edgeBot - ccdist;
-			if (errRect.r_ytop > errRect.r_ybot)
-			{
-			    /* result = 0; */ /* to be finished */
-			    result = DBSrPaintArea((Tile *) NULL,
-				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-				&errRect, &tmpMask, areaCheck, (ClientData) arg);
-			}
-
-			/* (to be done)(?) */
-		    }
-		    else 
-			result = DBSrPaintArea((Tile *) NULL,
+		    result = DBSrPaintArea((Tile *) NULL,
 				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
 				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 
@@ -825,13 +794,7 @@ checkbottom:
 		for (cptr = DRCRulesTbl[to][tt]; cptr != (DRCCookie *) NULL;
 				cptr = cptr->drcc_next)
 		{
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			ccdist = cptr->drcc_cdist;
-			cdist = cptr->drcc_dist;
-		    }
-		    else
-			cdist = cptr->drcc_cdist;
+		    cdist = cptr->drcc_cdist;
 
 		    /* Contact images exist in multple planes; only check	*/
 		    /* rules that are for the plane being checked.		*/
@@ -1017,32 +980,7 @@ checkbottom:
 		    DRCstatSlow++;
 		    arg->dCD_cptr = cptr;
 		    TTMaskCom2(&tmpMask, &cptr->drcc_mask);
-		    if (cptr->drcc_flags & DRC_CATECORNER)
-		    {
-			int tmpx = errRect.r_xbot;
-			errRect.r_xbot = edgeLeft + ccdist;
-			if (errRect.r_xbot < errRect.r_xtop)
-			{
-			    /* result = 0; */ /* to be finished */
-			    result = DBSrPaintArea((Tile *) NULL,
-				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-				&errRect, &tmpMask, areaCheck, (ClientData) arg);
-			}
-			errRect.r_xbot = tmpx;
-			tmpx = errRect.r_xtop;
-			errRect.r_xtop = edgeRight - ccdist;
-			if (errRect.r_xtop > errRect.r_xbot)
-			{
-			    /* result = 0; */ /* to be finished */
-			    result = DBSrPaintArea((Tile *) NULL,
-				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
-				&errRect, &tmpMask, areaCheck, (ClientData) arg);
-			}
-
-			/* (to be done)(?) */
-		    }
-		    else 
-			result = DBSrPaintArea((Tile *) NULL,
+		    result = DBSrPaintArea((Tile *) NULL,
 				arg->dCD_celldef->cd_planes[cptr->drcc_plane],
 				&errRect, &tmpMask, areaCheck, (ClientData) arg);
 
