@@ -780,10 +780,6 @@ drcMaxwidth(argc, argv)
  *
  *	spacing layers1 layers2 distance adjacency why
  *
- * or (added 3/28/05)
- *
- *	spacing layers1 layers2 distance catecorner dist2 why
- *
  * e.g,
  *
  *	spacing metal,pmc/m,dmc/m metal,pmc/m,dmc/m 4 touching_ok \
@@ -794,16 +790,6 @@ drcMaxwidth(argc, argv)
  * immediately adjacent to types in layers2.  In the second case,
  * such adjacency causes a violation.
  *
- * The "catecorner" option is designed for two purposes: 1) to catch
- * rule violations that are caused by a cifoutput grow rules followed
- * by a shrink rule.  If a tile is in the catecorner position between
- * distances (G-W) and G, where G is the amount grown, and W is the
- * minimum width of the CIF layer, then a strip of less than W would
- * result, and is therefore a DRC violation.  2) with dist2=0, can be
- * used to indicate that a layer can have no outside corners; that is,
- * corners must be beveled with a non-manhattan (usually 45 degree)
- * angle.
- *
  * Results:
  *	Returns distance.
  *
@@ -848,7 +834,6 @@ drcSpacing(argc, argv)
     TileType i, j;
     bool widerule = (strncmp(argv[0], "wide", 4) == 0);
     int wwidth;
-    bool catecorner = FALSE;
 
     if (widerule)
     {
@@ -867,28 +852,11 @@ drcSpacing(argc, argv)
 	distance = atoi(argv[3]);
 	adjacency = argv[4];
 	wwidth = distance;
-	if (!strcmp(adjacency, "catecorner"))
+	why = drcWhyDup(argv[5]);
+	if (argc == 7)
 	{
-	    if (argc == 7)
-	    {
-		wwidth = atoi(argv[5]);
-		why = drcWhyDup(argv[6]);
-		catecorner = TRUE;
-	    }
-	    else
-	    {
-		TechError("Not enough arguments in DRC catecorner spacing line.\n");
-		return(0);
-	    }
-	}
-	else
-	{
-	    why = drcWhyDup(argv[5]);
-	    if (argc == 7)
-	    {
-		TechError("Unknown argument in spacing line.\n");
-		return(0);
-	    }
+	    TechError("Unknown argument in spacing line.\n");
+	    return(0);
 	}
     }
 
@@ -920,16 +888,12 @@ drcSpacing(argc, argv)
 	    break;
     }
 
-    if (!strcmp(adjacency, "touching_ok") || catecorner)
+    if (!strcmp(adjacency, "touching_ok"))
     {
 	/* If touching is OK, everything must fall in the same plane. */
 	if (plane == DBNumPlanes)
 	{
-	    if (catecorner)
-	        TechError("Catecorner spacing check must have"
-			" all types in one plane.\n");
-	    else
-		TechError("Spacing check with touching ok must have"
+	    TechError("Spacing check with touching ok must have"
 			" all types in one plane.\n");
 	    return (0);
 	}
@@ -1059,9 +1023,6 @@ drcSpacing(argc, argv)
 		    if (needReverse)
 		        dpnew->drcc_flags |= DRC_BOTHCORNERS;
 
-		    if (catecorner)
-			dpnew->drcc_flags |= DRC_CATECORNER;
-
 		    if (needReverse)
 		    {
 			/* Add check in reverse direction, 
@@ -1141,9 +1102,6 @@ drcSpacing(argc, argv)
 		    if (needReverse)
 		        dpnew->drcc_flags |= DRC_BOTHCORNERS;
 
-		    if (catecorner)
-			dpnew->drcc_flags |= DRC_CATECORNER;
-
 		    dp->drcc_next = dpnew;		    
 
 		    if (needReverse)
