@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/graphics/grCMap.c,v 1.2 2001/01/12 22:12:45 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/graphics/grCMap.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -36,7 +36,7 @@ static char rcsid[]="$Header: /ufs/repository/magic/graphics/grCMap.c,v 1.2 2001
 #include "textio/textio.h"
 
 static colorEntry *colorMap = NULL;	/* Storage for the color map. */
-static int GrNumColors = 0;		/* Number of colors */
+int GrNumColors = 0;			/* Number of colors */
 
 
 /*-----------------------------------------------------------------------------
