@@ -4,7 +4,7 @@
  * This file defines things that are used by internal LEF routines in
  * various files.
  *
- * rcsid $Header: /ufs/repository/magic/lef/lefInt.h,v 1.1.1.1 2000/03/29 18:35:23 rajit Exp $
+ * rcsid $Header: /usr/cvsroot/magic/lef/lefInt.h,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $
  */
 
 #ifndef _LEFINT_H
@@ -27,8 +27,14 @@ typedef struct
 {
     int regular;
     int special;
+    bool has_nets;
 } NetCount;
 
+/* Various modes for writing nets. */
+#define DO_REGULAR  0
+#define DO_SPECIAL  1
+#define ALL_SPECIAL 2	/* treat all nets as SPECIALNETS */
+
 /* Struture used for returning information from a route or geometry section */
 
 typedef struct _linkedRect {
@@ -61,6 +67,13 @@ typedef struct {
 				/* more complicated geometry.		*/
 } lefVia;
 
+/* Defined types for "lefClass" in the lefLayer structure */
+
+#define CLASS_ROUTE	0	/* routing layer */
+#define CLASS_VIA	1	/* via or cut layer */
+#define CLASS_MASTER	2	/* masterslice layer */
+#define CLASS_OVERLAP	3	/* overlap layer */
+
 /* Structure defining a route or via layer and matching it to a magic	*/
 /* layer type.  This structure is saved in the LefInfo hash table.	*/
 /* To allow multiple names to refer to the same structure, we keep a	*/
@@ -68,13 +81,14 @@ typedef struct {
 /* this structure.							*/
 
 typedef struct {
-    TileType	 type;		/* magic tile type, or -1 for none */
-    TileType	 obsType;	/* magic type to use if this is an obstruction */
-    short	 refCnt;	/* reference count for memory deallocation */
-    bool	 is_via;	/* is this a via or route layer */
+    TileType	  type;		/* magic tile type, or -1 for none */
+    TileType	  obsType;	/* magic type to use if this is an obstruction */
+    short	  refCnt;	/* reference count for memory deallocation */
+    char *	  canonName;	/* name to use when writing LEF output */
+    unsigned char lefClass;	/* is this a via, route, or masterslice layer */
     union {
-	lefRoute route;		/* for route layers */
-	lefVia	 via;		/* for contacts */
+	lefRoute  route;	/* for route layers */
+	lefVia	  via;		/* for contacts */
     } info;
 } lefLayer;
 
