@@ -365,9 +365,9 @@ PlotVersTechLine(sectionName, argc, argv)
 	{
 	    (void) sscanf(argv[i+1], "%x", &value);
 	    new->vs_stipple[i] = (value<<16) | (value & 0xffff);
-#ifndef IS_BIG_ENDIAN
+#ifndef WORDS_BIGENDIAN
 	    new->vs_stipple[i] = PlotSwapBytes(new->vs_stipple[i]);
-#endif  /* IS_BIG_ENDIAN */
+#endif  /* WORDS_BIGENDIAN */
 	}
     }
 
@@ -476,9 +476,9 @@ PlotColorVersTechLine(sectionName, argc, argv)
 	{
 	    (void) sscanf(argv[i+2], "%x", &value);
 	    new->vs_stipple[i] = (value<<16) | (value & 0xffff);
-#ifndef IS_BIG_ENDIAN
+#ifndef WORDS_BIGENDIAN
 	    new->vs_stipple[i] = PlotSwapBytes(new->vs_stipple[i]);
-#endif  /* IS_BIG_ENDIAN */
+#endif  /* WORDS_BIGENDIAN */
 	}
     }
 
