@@ -19,7 +19,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/plow/PlowTech.c,v 1.2 2001/01/12 22:13:12 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/plow/PlowTech.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -834,6 +834,8 @@ PlowTechFinal()
 /*
  * ----------------------------------------------------------------------------
  *
+ * plowTechPrintRule --
+ * plowTechShowTable --
  * plowTechShow --
  *
  * For debugging purposes.
@@ -849,13 +851,24 @@ PlowTechFinal()
  */
 
 void
-plowTechShow(f)
+plowTechPrintRule(pr, f)
+    PlowRule *pr;
     FILE *f;
 {
-    plowTechShowTable(plowWidthRulesTbl, "Width Rules", f);
-    plowTechShowTable(plowSpacingRulesTbl, "Spacing Rules", f);
+    fprintf(f, "\tDISTANCE=%d, PLANE=%s, FLAGS=",
+		pr->pr_dist, DBPlaneLongName(pr->pr_pNum));
+    if (pr->pr_flags & PR_WIDTH) fprintf(f, " Width");
+    if (pr->pr_flags & PR_PENUMBRAONLY) fprintf(f, " PenumbraOnly");
+    if (pr->pr_flags & PR_EDGE) fprintf(f, " Edge");
+    if (pr->pr_flags & PR_EDGE4WAY) fprintf(f, " Edge4way");
+    if (pr->pr_flags & PR_EDGEBACK) fprintf(f, " EdgeBack");
+    fprintf(f, "\n");
+    fprintf(f, "\tLTYPES = %s\n", maskToPrint(&pr->pr_ltypes));
+    fprintf(f, "\tOKTYPES = %s\n", maskToPrint(&pr->pr_oktypes));
+    fprintf(f, "\t-------------------------------\n");
 }
 
+void
 plowTechShowTable(table, header, f)
     PlowRule *table[TT_MAXTYPES][TT_MAXTYPES];
     char *header;
@@ -876,19 +889,11 @@ plowTechShowTable(table, header, f)
 	    }
 }
 
-plowTechPrintRule(pr, f)
-    PlowRule *pr;
+void
+plowTechShow(f)
     FILE *f;
 {
-    fprintf(f, "\tDISTANCE=%d, PLANE=%s, FLAGS=",
-		pr->pr_dist, DBPlaneLongName(pr->pr_pNum));
-    if (pr->pr_flags & PR_WIDTH) fprintf(f, " Width");
-    if (pr->pr_flags & PR_PENUMBRAONLY) fprintf(f, " PenumbraOnly");
-    if (pr->pr_flags & PR_EDGE) fprintf(f, " Edge");
-    if (pr->pr_flags & PR_EDGE4WAY) fprintf(f, " Edge4way");
-    if (pr->pr_flags & PR_EDGEBACK) fprintf(f, " EdgeBack");
-    fprintf(f, "\n");
-    fprintf(f, "\tLTYPES = %s\n", maskToPrint(&pr->pr_ltypes));
-    fprintf(f, "\tOKTYPES = %s\n", maskToPrint(&pr->pr_oktypes));
-    fprintf(f, "\t-------------------------------\n");
+    plowTechShowTable(plowWidthRulesTbl, "Width Rules", f);
+    plowTechShowTable(plowSpacingRulesTbl, "Spacing Rules", f);
 }
+
