@@ -5,22 +5,18 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resi
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
 
 /* It is hard to get the value of MAXFLOAT in a portable manner. */
-#if defined(ibm032) || defined(CYGWIN) || defined(macosx) 
+#if defined(ibm032)
 #define MAXFLOAT        ((float)3.40282346638528860e+38)
-#elif !defined(__NetBSD__)
+#elif !defined(__NetBSD__) && !defined(__FreeBSD__) && !defined(CYGWIN) && !defined(macosx) 
 #include <values.h>
 #endif
 
 #undef	MAXINT
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
