@@ -12,13 +12,9 @@
 static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/resis/ResSimple.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 #include <stdio.h>
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
-#ifdef	SYSV
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
