@@ -17,14 +17,12 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/router/routeCmd.c,v 1.0 2001/03/29 19:50:05 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrCmd.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
-#include <ctype.h>
-#ifdef SYSV
 #include <string.h>
-#endif
+#include <ctype.h>
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
