@@ -16,7 +16,7 @@
  */
 
 #ifndef lint
-static char rcsid[]="$Header: /ufs/repository/magic/router/rtrMain.c,v 1.2 2001/01/12 22:13:18 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/router/rtrMain.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -48,6 +48,9 @@ static char rcsid[]="$Header: /ufs/repository/magic/router/rtrMain.c,v 1.2 2001/
 /* Forward declarations */
 
 extern int rtrMakeChannel();
+void RtrMilestoneStart(char *);
+void RtrMilestoneDone();
+
 
 /*
  * The origin point for the routing grid.
@@ -246,6 +249,7 @@ RtrRunStats()
     TxFlush();
 }
 
+void 
 RtrMilestoneStart(event)
     char *event;
 {
@@ -256,6 +260,7 @@ RtrMilestoneStart(event)
     rtrFeedCount = DBWFeedbackCount;
 }
 
+void
 RtrMilestoneDone()
 {
     struct tms tend;
@@ -266,6 +271,7 @@ RtrMilestoneDone()
 		(tend.tms_stime - rtrStartTime.tms_stime) / 60.0);
 }
 
+void
 RtrMilestonePrint()
 {
     TxPrintf("%c", (DBWFeedbackCount > rtrFeedCount) ? '!' : '#');
