@@ -1021,14 +1021,14 @@ Tclmagic_Init(interp)
 
     Tcl_Eval(interp, "lappend auto_path " TCL_DIR );
 
-    /* Set $CAD_HOME as a Tcl variable */
+    /* Set $CAD_ROOT as a Tcl variable */
 
-    cadhome = getenv("CAD_HOME");
+    cadhome = getenv("CAD_ROOT");
     if (cadhome == NULL) cadhome = CAD_DIR;
 
-    Tcl_SetVar(interp, "CAD_HOME", cadhome, TCL_GLOBAL_ONLY);
+    Tcl_SetVar(interp, "CAD_ROOT", cadhome, TCL_GLOBAL_ONLY);
 
-    Tcl_PkgProvide(interp, "Tclmagic", "7.3");
+    Tcl_PkgProvide(interp, "Tclmagic", MAGIC_VERSION);
     return TCL_OK;
 }
 
