@@ -15,7 +15,7 @@
  *     * of the United States of America may require an export license.    * 
  *     *********************************************************************
  *
- * rcsid $Header: /ufs/repository/magic/textio/txcommands.h,v 1.3 2001/03/29 19:50:12 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic/textio/txcommands.h,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $
  */
 
 #ifndef _TXCOMMANDS_H
@@ -96,6 +96,8 @@ typedef struct {
 #define TX_EOF			0x80	/* Never leaves this module, it is
 					 * filtered out.
 					 */
+#define TX_BUTTON_4		0x100	/* For scroll wheels and such */
+#define TX_BUTTON_5		0x200	/* For scroll wheels and such */
 
 #ifdef MAGIC_WRAPPER
 extern TxCommand TxCurCommand;
@@ -148,8 +150,5 @@ extern void TxFreeCommand();
 extern void TxParseString();
 extern void TxDispatch();
 extern int TxCommandNumber;	/* Serial number of current command. */
-#ifdef MAGIC_WRAPPER
-extern bool TxTkConsole;	/* Tk Console for I/O */
-#endif
 
 #endif /* _TXCOMMANDS_H */
