@@ -46,7 +46,7 @@ static MagWindow *sharedW;
  * By default, new windows have scroll bars, border, a title caption,
  * and allow standard window commands.
  */
-bool windDefaultFlags = WIND_SCROLLBARS | WIND_CAPTION |
+int WindDefaultFlags = WIND_SCROLLBARS | WIND_CAPTION |
 			WIND_BORDER | WIND_COMMANDS |
 			WIND_SCROLLABLE;
 
@@ -280,7 +280,7 @@ WindCreate(client, frameArea, isHint, argc, argv)
     /* initialize the window */
     w = (MagWindow *) mallocMagic( sizeof(MagWindow) );
     w->w_client = client;
-    w->w_flags = windDefaultFlags;
+    w->w_flags = WindDefaultFlags;
     w->w_clipAgainst = (LinkedRect *) NULL;
     w->w_caption = (char *) NULL;
     w->w_stippleOrigin.p_x = 0;
